var LangText={
	"en": {
		"t1": "Welcome to Bambu Studio",
		"t2": "Bambu Studio will be setup in several steps. Let's start!",
		"t3": "User Agreement",
		"t4": "Disagree",
		"t5": "Agree",
		"t6": "We kindly request your help to improve everyone's printing.<br/>Come and Join our Customer Experience Improvement Program",
		"t7": "Join our Customer Experience Improvement Program",
		"t8": "Back",
		"t9": "Next",
		"t10": "Printer Selection",
		"t11": "All",
		"t12": "Clear all",
		"t13": "mm nozzle",
		"t14": "Filament Selection",
		"t15": "Printer",
		"t16": "Filament type",
		"t17": "Vendor",
		"t18": "error",
		"t19": "At least one filament must be selected.",
		"t20": "Do you want to use default filament ?",
		"t21": "yes",
		"t22": "no",
		"t23": "Release note",
		"t24": "Get Started",
		"t25": "Finish",
		"t26": "Login",
		"t27": "Register",
		"t28": "Models",
		"t29": "Mall",
		"t30": "Manual",
		"t31": "New Project",
		"t32": "Create new project",
		"t33": "Open Project",
		"t34": "hotspot",
		"t35": "Recently Opened",
		"t36": "ok",
		"t37": "At least one printer must be selected.",
		"t38": "Cancel",
		"t39": "Confirm",
		"t40": "Network disconnect, please check and try again later.",
		"t47": "Please select your login region",
		"t48": "Asia-Pacific",
		"t49": "Chinese Mainland",
		"t50": "Log out",
		"t52": "Skip",
		"t53": "Join",
		"t54": "In the 3D Printing community, we learn from each other's successes and failures to adjust our own slicing parameters and settings. Bambu Studio follows the same principle and uses machine learning to improve its performance from the successes and failures of the vast number of prints by our users. We are training Bambu Studio to be smarter by feeding them the real-world data. If you are willing, this service will access information from your error logs and usage logs, which may include information described in ",
		"t55": "Privacy Policy",
		"t56": ". We will not collect any Personal Data by which an individual can be identified directly or indirectly, including without limitation names, addresses, payment information, or phone numbers. By enabling this service, you agree to these terms and the statement about Privacy Policy.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europe",
		"t61": "North America",
		"t62": "Others",
		"t63": "After changing the region, your account will be logged out. Please log in again later.",
		"t64": "Bambu Network plug-in",
		"t65": "Sending print job via WLAN or cloud service",
		"t66": "Full remote control",
		"t67": "Liveview streaming and printer status monitor",
		"t68": "Cloud synchronization for slicing configuration",
		"t69": "Install Bambu Network plug-in",
		"t70": "",
		"t71": "Downloading",
		"t72": "Downloading failed",
		"t73": "Installation successful.",
		"t74": "Restart",
		"t75": "Bambu Network plug-in provides the following features:",
		"t76": "Please ",
		"t77": "install",
		"t78": " the network plugin before logging in",
		"t79": "Failed to install plug-in. ",
		"t80": "Try the following steps:",
		"t81": "1, Click ",
		"t82": " to open the plug-in directory",
		"t83": "2, Close all open Bambu Studio",
		"t84": "3, Delete all files under the plug-in directory",
		"t85": "4, Reopen Bambu studio and install the plug-in again",
		"t86": "Close",
		"t87": "User Manual",
		"t88": "Remove",
		"t89": "Open Containing Folder",
		"t90": "3D Model",
		"t91": "Download 3D models",
		"t92": "Create by",
		"t93": "Remixed by",
		"t94": "Shared by",
		"t95": "Model Information",
		"t96": "Accessories",
		"t97": "Profile Information",
		"t98": "Model name",
		"t100": "Model description",
		"t101": "BOM",
		"t102": "Assembly Guide",
		"t103": "Other",
		"t104": "Profile name",
		"t105": "Profile Author",
		"t106": "Profile description",
		"t107": "Online Models",
		"t108": "MORE",
		"t109": "System Filaments",
		"t110": "Custom Filaments",
		"t111": "Create New",
		"t112": "Join the Program",
		"t113": "You may change your choice in preference anytime.",
		"t114": "Library",
		"t115": "Batch",
		"t116": "Retry",
		"t117": "Print History",
		"t118": "Printing",
		"t119": "Success",
		"t120": "Canceled",
		"t121": "Search",
		"t122": "Search online models",
		"t123": "Plate",
		"t124": "",
		"t125": "Maker’s Supply",
		"t126": "Loading……",
		"wk17": "Bambu Lab Academy",
		"wk18": "Quick Start Tutorial",
		"wk19": "Learn by Topic",
		"wk20": "Filament Guide",
		"wk21": "Explore now"
	},
	"zh_CN": {
		"t1": "欢迎使用Bambu Studio",
		"t2": "Bambu Studio需要几步安装步骤，让我们开始吧！",
		"t3": "用户使用协议",
		"t4": "拒绝",
		"t5": "同意",
		"t6": "帮助提升Bambu Studio性能<br/>欢迎加入我们的客户体验改善计划",
		"t7": "允许发送匿名数据",
		"t8": "上一步",
		"t9": "下一步",
		"t10": "选择打印机",
		"t11": "全部",
		"t12": "清空",
		"t13": "mm 喷嘴",
		"t14": "选择材料",
		"t15": "打印机",
		"t16": "材料类型",
		"t17": "供应商",
		"t18": "错误",
		"t19": "至少要选择一款材料。",
		"t20": "你希望使用默认的材料列表吗?",
		"t21": "是",
		"t22": "否",
		"t23": "发布说明",
		"t24": "开始",
		"t25": "结束",
		"t26": "登录",
		"t27": "注册",
		"t28": "模型",
		"t29": "商城",
		"t30": "使用手册",
		"t31": "新建项目",
		"t32": "创建一个新项目",
		"t33": "打开项目",
		"t34": "热点",
		"t35": "近期打开文件",
		"t36": "确定",
		"t37": "至少需要选择一款打印机。",
		"t38": "取消",
		"t39": "确定",
		"t40": "网络不通，请检查并稍后重试。",
		"t47": "请选择登录区域",
		"t48": "亚太",
		"t49": "中国内地(大陆)",
		"t50": "退出登录",
		"t52": "忽略",
		"t53": "同意",
		"t54": "在3D打印社区，我们从彼此的成功和失败中学习调整自己的切片参数和设置。Bambu Studio遵循同样的原则，通过机器学习的方式从大量用户打印的成功和失败中获取经验，从而改善打印性能。我们正在通过向Bambu Studio提供真实世界的数据来训练他们变得更聪明。如果您愿意，此服务将访问您的错误日志和使用日志中的信息，其中可能包括",
		"t55": "隐私政策",
		"t56": "中描述的信息。我们不会收集任何可以直接或间接识别个人的个人数据，包括但不限于姓名、地址、支付信息或电话号码。启用此服务即表示您同意这些条款和有关隐私政策的声明。",
		"t57": "",
		"t58": "",
		"t59": "。",
		"t60": "欧洲",
		"t61": "北美",
		"t62": "其他",
		"t63": "切换区域后，你的账号会被登出。稍后请重新登录。",
		"t64": "Bambu网络插件",
		"t65": "通过局域网或云服务发送打印任务",
		"t66": "强大的远程控制功能",
		"t67": "实时视频流和打印机状态管理",
		"t68": "通过云端同步切片设置",
		"t69": "安装Bambu网络插件",
		"t70": "",
		"t71": "正在下载",
		"t72": "下载失败",
		"t73": "安装成功。",
		"t74": "重启",
		"t75": "Bambu网络插件提供以下功能：",
		"t76": "请在登陆前",
		"t77": "安装",
		"t78": "网络插件",
		"t79": "安装插件失败。",
		"t80": "请尝试如下步骤：",
		"t81": "1, 点击",
		"t82": "打开插件所在目录",
		"t83": "2, 关闭所有Bambu Studio",
		"t84": "3, 删除插件所在目录下的所有文件",
		"t85": "4, 重新启动Bambu Studio并尝试安装插件",
		"t86": "关闭",
		"t87": "使用引导",
		"t88": "移除",
		"t89": "打开所在的文件夹",
		"t90": "3D 模型",
		"t91": "下载3D模型",
		"t92": "创作",
		"t93": "修改",
		"t94": "分享",
		"t95": "模型信息",
		"t96": "附件",
		"t97": "配置信息",
		"t98": "模型名称",
		"t100": "模型介绍",
		"t101": "物料清单",
		"t102": "装备指导",
		"t103": "其他",
		"t104": "配置名称",
		"t105": "配置作者",
		"t106": "配置介绍",
		"t107": "在线模型",
		"t108": "更多",
		"t109": "系统材料",
		"t110": "自建材料",
		"t111": "新建",
		"t112": "加入该计划",
		"t113": "您可以随时更改您的偏好。",
		"t114": "模型库",
		"t115": "批量处理",
		"t116": "重试",
		"t117": "打印历史",
		"t118": "正在打印",
		"t119": "成功",
		"t120": "已取消",
		"t121": "搜索",
		"t122": "搜索在线模型",
		"t123": "第",
		"t124": " 盘",
		"t125": "创客宝库",
		"t126": "正在加载……",
		"wk1": "快速入门指南",
		"wk2": "本文介绍了Bambu Studio的最基本用法。它指导用户配置软件，创建项目，并逐步完成第一个打印任务。",
		"wk3": "基于项目的工作流",
		"wk4": "Bambu Studio提出了领先的工作流程，真正实现了“一体化”项目。基于主流的3MF项目格式，它提供了一系列革命性的新功能，如支持多盘、项目资源管理器和装配/零件视图。它可以大幅提高模型创作者及普通用户的使用效率。",
		"wk5": "质量卓越的高速打印",
		"wk6": "在保持高质量的前提下进行高速打印是非常具有挑战性的。Bambu Studio让这一切发生。支持“圆弧移动”特性使工具头移动更加顺滑，有效减少机器振动。基于不同材料类型的精细标定过的冷却控制参数，使得冷却过程可以自动开展。在悬垂区域进行“自动减速”，可防止高速打印时在此区域的外观瑕疵。",
		"wk7": "多色打印",
		"wk8": "Bambu Studio提供了多种着色工具来制作彩色模型。您可以在项目中自由添加/移除打印材料，并使用不同的笔刷为模型着色。开始打印时，打印任务中的各个材料将自动映射到匹配的AMS槽位，无需手动调整AMS中的料卷位置。",
		"wk9": "切片参数设置指南",
		"wk10": "Bambu Studio中的参数管理功能为切片过程提供了非常灵活和强大的控制。本文介绍了切片参数的组织分类和设置方法，并提供了一些使用技巧。",
		"wk11": "远程控制和监控",
		"wk12": "Bambu Studio支持通过WAN/LAN网络向打印机发送打印任务，控制和查看3D打印机和打印任务的各个方面。如果您有多台打印机，还可以在设备列表中轻松切换。",
		"wk13": "STEP格式",
		"wk14": "与STL相比，STEP带来了更多有效的信息。由于STEP的高精度，切片时可以生成更多的圆弧路径。STEP还包括模型每个零件的装配关系，可分割模型后恢复装配视图。",
		"wk15": "3D文本",
		"wk16": "使用3D文本工具，用户可以轻松地在项目中创建各种3D文本形状，使模型更加个性化。Bambu Studio提供了数十种字体，并支持粗体和斜体样式，使文本具有更大的灵活性。",
		"wk17": "拓竹学院",
		"wk18": "快速入门指南",
		"wk19": "按主题学习",
		"wk20": "材料指南",
		"wk21": "立即探索"
	},
	"ja_JP": {
		"t1": "Bambu Studioへようこそ",
		"t2": "セットアップ",
		"t3": "利用規約",
		"t4": "同意しない",
		"t5": "同意",
		"t6": "ユーザ体験向上プログラム<br/>デルのカスタマーエクスペリエンス改善プログラムへようこそ",
		"t7": "匿名で送信することを許容",
		"t8": "戻る",
		"t9": "次へ",
		"t10": "プリンター選択",
		"t11": "全て",
		"t12": "全てを解除",
		"t13": "mm ノズル",
		"t14": "フィラメント選択",
		"t15": "プリンター",
		"t16": "フィラメントタイプ",
		"t17": "メーカー",
		"t18": "エラー",
		"t19": "最低限一つのフィラメントを選択する必要があります",
		"t20": "デフォルトのフィラメントにしますか？",
		"t21": "はい",
		"t22": "いいえ",
		"t23": "リリースノート",
		"t24": "利用開始",
		"t25": "完了",
		"t26": "サインイン",
		"t27": "登録",
		"t28": "モデル",
		"t29": "モール",
		"t30": "マニュアル",
		"t31": "新規プロジェクト",
		"t32": "プロジェクトを作成",
		"t33": "プロジェクトを開く",
		"t34": "ホットスポット",
		"t35": "最近開いた項目",
		"t36": "OK",
		"t37": "最低限一つのプリンターを選択する必要があります",
		"t38": "取消し",
		"t39": "確認",
		"t40": "ネットワークが切断されたのようです、もう一度も試しください",
		"t47": "地域を選択してください",
		"t48": "アジア-太平洋",
		"t49": "中国本土",
		"t50": "サインアウト",
		"t52": "スキップ",
		"t53": "参加する",
		"t54": "3Dプリンティングのコミュニティで、私たちはお互いの成功例と失敗例から色々勉強してきています。Bambu Labもそうと考えています、AIでユーザの実世界の経験から勉強し、造型の性能を向上しにいきたいと思います。あなたの経験は私たちにとって大切なので、私たちの「ユーザ体験向上プログラム」を参加してみませんか？「参加」する場合、エラーログや使用ログから情報をBambu Labと共有します、具体的な項目は",
		"t55": "プライバシーポリシー",
		"t56": "をご参照ください。個人情報は一切共有しませんのでご安心ください。",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "欧州",
		"t61": "北米",
		"t62": "その他",
		"t63": "地域を変更したら、一回サインアウトされます。もう一度サインインしてください",
		"t64": "Bambu ネットワークプラグイン",
		"t65": "印刷ジョブをWLANまたはクラウドサービスで送信する",
		"t66": "リモートコントロール",
		"t67": "ライブビューストリーミングとプリンター状態モニタリング",
		"t68": "スライシング設定のクラウド同期",
		"t69": "Bambu ネットワークプラグインをインストール",
		"t70": "",
		"t71": "ダウンロード中",
		"t72": "ダウンロード失敗",
		"t73": "インストールは成功しました",
		"t74": "再起動",
		"t75": "Bambu ネットワークプラグインは以下の機能を提供します：",
		"t76": "ログイン前にネットワークプラグインをインストールしてください。",
		"t77": "インストールしてください",
		"t78": "",
		"t79": "インストールは失敗しました",
		"t80": "下記の方法もお試しください",
		"t81": "1. クリックして ",
		"t82": "プラグイン フォルダを開く",
		"t83": "2. 全て開いたBambu Studioを閉じる",
		"t84": "3. プラグイン フォルダのファイルを全て削除",
		"t85": "4. Bambu Studioを開く、再度プラグインをインストールしてください",
		"t86": "閉じる",
		"t87": "ユーザ マニュアル",
		"t88": "削除",
		"t89": "フォルダを開く",
		"t90": "3Dモデル",
		"t91": "モデルをダウンロード",
		"t92": "創作",
		"t93": "修正",
		"t94": "共有",
		"t95": "モデル情報",
		"t96": "添付ファイル",
		"t97": "構成情報",
		"t98": "モデル名",
		"t100": "モデルの紹介",
		"t101": "BOM",
		"t102": "装備指導",
		"t103": "その他",
		"t104": "構成名",
		"t105": "構成著者",
		"t106": "構成の概要",
		"t107": "オンラインモデル",
		"t108": "もっと",
		"t109": "システムフィラメント",
		"t110": "カスタムフィラメント",
		"t111": "新規作成",
		"t112": "この計画に参加する",
		"t113": "好みはいつでも変更できます.",
		"t114": "ライブラリ",
		"t115": "バッチ",
		"t116": "[再試行]",
		"t117": "印刷履歴",
		"t118": "印刷中",
		"t119": "成功",
		"t120": "キャンセルされた",
		"t121": "検索",
		"t122": "オンラインモデルを検索する",
		"t123": "シート材",
		"t124": "",
		"t126": "読み込み中……",
		"wk17": "バンブーラボ アカデミー",
		"wk18": "クイックスタート チュートリアル",
		"wk19": "トピック別に学ぶ",
		"wk20": "フィラメント ガイド",
		"wk21": "今すぐ探索"
	},
	"it_IT": {
		"t1": "Benvenuti allo Studio Bambu",
		"t2": "Lo Studio Bambu verrà impostato in diversi passaggi. Iniziamo!",
		"t3": "Accordo dell'utente",
		"t4": "Non accetto",
		"t5": "Accetto",
		"t6": "Chiediamo gentilmente il tuo aiuto per migliorare la stampa di tutti. Vieni a partecipare al nostro programma di miglioramento della customer experience",
		"t7": "Partecipa al nostro programma di miglioramento dell'esperienza cliente",
		"t8": "Indietro",
		"t9": "Avanti",
		"t10": "Selezione della stampante",
		"t11": "Tutti",
		"t12": "Cancella tutto",
		"t13": "mm ugello",
		"t14": "Selezione del filamento",
		"t15": "Stampante",
		"t16": "Tipo di filamento",
		"t17": "Venditore",
		"t18": "Errore",
		"t19": "È necessario selezionare almeno un filamento.",
		"t20": "Vuoi utilizzare il filamento predefinito?",
		"t21": "sì",
		"t22": "no",
		"t23": "Note sulla versione",
		"t24": "Inizia",
		"t25": "Fine",
		"t26": "Accesso",
		"t27": "Registrati",
		"t28": "Modelli",
		"t29": "Mall",
		"t30": "Manuale",
		"t31": "Nuovo progetto",
		"t32": "Crea nuovo progetto",
		"t33": "Apri progetto",
		"t34": "hotspot",
		"t35": "Aperti di recente",
		"t36": "ok",
		"t37": "È necessario selezionare almeno una stampante.",
		"t38": "Annulla",
		"t39": "Conferma",
		"t40": "Disconnessione di rete, controlla e riprova più tardi.",
		"t47": "Seleziona la tua regione di accesso",
		"t48": "Asia-Pacifico",
		"t49": "Cina continentale",
		"t50": "Esci",
		"t52": "Salta",
		"t53": "Unisciti",
		"t54": "Nella comunità di stampa 3D, impariamo dai successi e dagli insuccessi degli altri per regolare i nostri stessi parametri e impostazioni di slicing. Lo Studio Bambu segue lo stesso principio e utilizza l'apprendimento automatico per migliorare le sue prestazioni dai successi e insuccessi del vasto numero di stampe dei nostri utenti. Stiamo addestrando Bambu Studio a essere più intelligente alimentandolo con i dati del mondo reale. Se sei disposto, questo servizio accederà alle informazioni dai tuoi log degli errori e di utilizzo, che possono includere informazioni descritte in ",
		"t55": "Informativa sulla privacy",
		"t56": ". Non raccoglieremo alcun dato personale attraverso cui un individuo possa essere identificato direttamente o indirettamente, incluso ma non limitato a nomi, indirizzi, informazioni di pagamento o numeri di telefono. Abilitando questo servizio, accetti questi termini e la dichiarazione sulla Privacy Policy.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "Nord America",
		"t62": "Altri",
		"t63": "Dopo aver cambiato la regione, il tuo account verrà disconnesso. Effettua nuovamente il login più tardi.",
		"t64": "Plug-in di Bambu Network",
		"t65": "Invio del lavoro di stampa tramite WLAN o servizio cloud",
		"t66": "Controllo remoto completo",
		"t67": "Streaming Liveview e monitoraggio dello stato della stampante",
		"t68": "Sincronizzazione cloud per la configurazione del taglio",
		"t69": "Installa il plug-in di Bambu Network",
		"t70": "",
		"t71": "Download in corso",
		"t72": "Download fallito",
		"t73": "Installazione completata.",
		"t74": "Riavvia",
		"t75": "Il plug-in di Bambu Network fornisce le seguenti funzionalità:",
		"t76": "Si prega di ",
		"t77": "installare",
		"t78": "il plugin di rete prima di accedere",
		"t79": "Installazione del plug-in non riuscita. ",
		"t80": "Prova i seguenti passaggi:",
		"t81": "1. Fai clic su ",
		"t82": " per aprire la directory del plug-in",
		"t83": "2. Chiudi tutte le istanze di Bambu Studio aperte",
		"t84": "3. Elimina tutti i file nella directory del plug-in",
		"t85": "4. Riapri Bambu Studio e installa di nuovo il plug-in",
		"t86": "Chiudi",
		"t87": "Manuale utente",
		"t88": "Rimuovi",
		"t89": "Apri cartella contenente",
		"t90": "Modello 3D",
		"t91": "Scarica modelli 3D",
		"t92": "Creato da",
		"t93": "Remixato da",
		"t94": "Condiviso da",
		"t95": "Informazioni sul modello",
		"t96": "Accessori",
		"t97": "Informazioni sul profilo",
		"t98": "Nome del modello",
		"t100": "Descrizione del modello",
		"t101": "BOM",
		"t102": "Guida all'assemblaggio",
		"t103": "Altro",
		"t104": "Nome del profilo",
		"t105": "Autore del profilo",
		"t106": "Descrizione del profilo",
		"t107": "Modelli online",
		"t108": "più",
		"t109": "Filamenti di Sistema",
		"t110": "Filamenti Personalizzati",
		"t111": "Crea Nuovo",
		"t112": "Partecipa al programma",
		"t113": "Puoi cambiare la tua scelta in qualsiasi momento.",
		"t114": "Libreria",
		"t115": "Lotto",
		"t116": "Riprova",
		"t117": "Storico di stampa",
		"t118": "Stampa in corso",
		"t119": "Successo",
		"t120": "annullato",
		"t121": "Ricerca",
		"t122": "Cerca modelli online",
		"t123": "piatto",
		"t124": "",
		"t126": "Caricamento in corso……",
		"wk17": "Bambu Lab Accademia",
		"wk18": "Tutorial di Avvio Rapido",
		"wk19": "Impara per Argomento",
		"wk20": "Guida al Filamento",
		"wk21": "Esplora ora"
	},
	"fr_FR": {
		"t1": "Bienvenue chez Bambu Studio",
		"t2": "Bambu Studio sera configuré en plusieurs étapes. Commençons !",
		"t3": "Contrat d'utilisateur",
		"t4": "Désaccord",
		"t5": "Accord",
		"t6": "Nous sollicitons votre aide pour améliorer l'impression de chacun. Bienvenue dans notre programme d'amélioration de l'expérience client",
		"t7": "Rejoignez notre programme d'amélioration de l'expérience client",
		"t8": "Retour",
		"t9": "Suivant",
		"t10": "Sélection d'imprimante",
		"t11": "Tous",
		"t12": "Tout effacer",
		"t13": "mm buse",
		"t14": "Sélection de filament",
		"t15": "Imprimante",
		"t16": "Type de filament",
		"t17": "Vendeur",
		"t18": "Erreur",
		"t19": "Au moins un filament doit être sélectionné.",
		"t20": "Voulez-vous utiliser le filament par défaut ?",
		"t21": "oui",
		"t22": "non",
		"t23": "Notes de version",
		"t24": "Commencer",
		"t25": "Terminer",
		"t26": "Connexion",
		"t27": "S'inscrire",
		"t28": "Modèles",
		"t29": "Centre commercial",
		"t30": "Manuel",
		"t31": "Nouveau projet",
		"t32": "Créer un nouveau projet",
		"t33": "Ouvrir un projet",
		"t34": "point d'accès",
		"t35": "Récemment ouvert",
		"t36": "OK",
		"t37": "Au moins une imprimante doit être sélectionnée.",
		"t38": "Annuler",
		"t39": "Confirmer",
		"t40": "Déconnexion du réseau, veuillez vérifier et réessayer ultérieurement.",
		"t47": "Veuillez sélectionner votre région de connexion",
		"t48": "Asie-Pacifique",
		"t49": "Chine continentale",
		"t50": "Se déconnecter",
		"t52": "Passer",
		"t53": "Rejoindre",
		"t54": "Dans la communauté de l'impression 3D, nous apprenons des succès et des échecs des autres pour ajuster nos propres paramètres de tranchage et de réglages. Bambu Studio suit le même principe et utilise l'apprentissage automatique pour améliorer ses performances à partir des succès et des échecs du grand nombre d'impressions de nos utilisateurs. Nous entraînons Bambu Studio à devenir plus intelligent en lui fournissant des données du monde réel. Si vous le souhaitez, ce service accédera aux informations de vos journaux d'erreurs et de vos journaux d'utilisation, qui peuvent inclure des informations décrites dans ",
		"t55": "Politique de confidentialité",
		"t56": ". Nous ne collecterons aucune donnée personnelle permettant d'identifier directement ou indirectement une personne, y compris sans limitation les noms, adresses, informations de paiement ou numéros de téléphone. En activant ce service, vous acceptez ces termes ainsi que la déclaration sur la politique de confidentialité.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europe",
		"t61": "Amérique du Nord",
		"t62": "Autres",
		"t63": "Après avoir modifié la région, votre compte sera déconnecté. Veuillez vous reconnecter plus tard.",
		"t64": "Plug-in Réseau Bambu",
		"t65": "Envoi de tâches d'impression via WLAN ou service cloud",
		"t66": "Contrôle complet à distance",
		"t67": "Streaming Liveview et surveillance de l'état de l'imprimante",
		"t68": "Synchronisation cloud pour la configuration de tranchage",
		"t69": "Installer le plug-in Réseau Bambu",
		"t70": "",
		"t71": "Téléchargement en cours",
		"t72": "Échec du téléchargement",
		"t73": "Installation réussie.",
		"t74": "Redémarrer",
		"t75": "Le plug-in Réseau Bambu offre les fonctionnalités suivantes :",
		"t76": "Veuillez ",
		"t77": "installer",
		"t78": " le plugin réseau avant de vous connecter",
		"t79": "Échec de l'installation du plug-in. ",
		"t80": "Suivez les étapes suivantes :",
		"t81": "1, Cliquez ",
		"t82": " pour ouvrir le répertoire du plug-in",
		"t83": "2, Fermez tous les Bambu Studio ouverts",
		"t84": "3, Supprimez tous les fichiers du répertoire du plug-in",
		"t85": "4, Ré-ouvrez Bambu studio et installez le plug-in à nouveau",
		"t86": "Fermer",
		"t87": "Manuel d'utilisateur",
		"t88": "Supprimer",
		"t89": "Ouvrir le dossier contenant",
		"t90": "Modèle 3D",
		"t91": "Télécharger des modèles 3D",
		"t92": "Créé par",
		"t93": "Remixé par",
		"t94": "Partagé par",
		"t95": "Informations sur le modèle",
		"t96": "Accessoires",
		"t97": "Informations de profil",
		"t98": "Nom du modèle",
		"t100": "Description du modèle",
		"t101": "BOM",
		"t102": "Guide d'assemblage",
		"t103": "Autre",
		"t104": "Nom du profil",
		"t105": "Auteur du profil",
		"t106": "Description du profil",
		"t107": "Modèles en ligne",
		"t108": "plus",
		"t109": "Filaments Système",
		"t110": "Filaments Personnalisés",
		"t111": "Créer Nouveau",
		"t112": "Rejoignez le programme",
		"t113": "Vous pouvez modifier vos préférences à tout moment.",
		"t114": "Bibliothèque",
		"t115": "Un lot de",
		"t116": "Retenter",
		"t117": "Historique d'impression",
		"t118": "Impression en cours",
		"t119": "Succès",
		"t120": "annulé",
		"t121": "Recherche",
		"t122": "Rechercher des modèles en ligne",
		"t123": "assiette",
		"t124": "",
		"t126": "Chargement en cours……",
		"wk17": "Académie Bambu Lab",
		"wk18": "Tutoriel de Démarrage Rapide",
		"wk19": "Apprendre par sujet",
		"wk20": "Guide des filaments",
		"wk21": "Explorer maintenant"
	},
	"de_DE": {
		"t1": "Willkommen im Bambu Studio",
		"t2": "Das Bambu Studio wird in mehreren Schritten eingerichtet. Lass uns anfangen!",
		"t3": "Nutzervereinbarung",
		"t4": "Nicht einverstanden",
		"t5": "Einverstanden",
		"t6": "Wir bitten um Ihre Hilfe, um den Druck für alle zu verbessern. Kommen Sie und nehmen Sie an unserem Programm zur Verbesserung der Kundenerfahrung teil",
		"t7": "Treten Sie unserem Kundenverbesserungsprogramm bei",
		"t8": "Zurück",
		"t9": "Weiter",
		"t10": "Druckerauswahl",
		"t11": "Alle",
		"t12": "Alle löschen",
		"t13": "mm Düse",
		"t14": "Filamentauswahl",
		"t15": "Drucker",
		"t16": "Filamenttyp",
		"t17": "Anbieter",
		"t18": "Fehler",
		"t19": "Mindestens ein Filament muss ausgewählt werden.",
		"t20": "Möchten Sie das Standardfilament verwenden?",
		"t21": "Ja",
		"t22": "Nein",
		"t23": "Versionshinweis",
		"t24": "Loslegen",
		"t25": "Fertig",
		"t26": "Anmelden",
		"t27": "Registrieren",
		"t28": "Modelle",
		"t29": "Einkaufszentrum",
		"t30": "Handbuch",
		"t31": "Neues Projekt",
		"t32": "Neues Projekt erstellen",
		"t33": "Projekt öffnen",
		"t34": "Hotspot",
		"t35": "Zuletzt geöffnet",
		"t36": "OK",
		"t37": "Mindestens ein Drucker muss ausgewählt werden.",
		"t38": "Abbrechen",
		"t39": "Bestätigen",
		"t40": "Netzwerkfehler, bitte überprüfen und später erneut versuchen.",
		"t47": "Bitte wählen Sie Ihre Anmelde-Region",
		"t48": "Asien-Pazifik",
		"t49": "Chinesisches Festland",
		"t50": "Abmelden",
		"t52": "Überspringen",
		"t53": "Beitreten",
		"t54": "In der 3D-Druck-Community lernen wir aus den Erfolgen und Fehlern anderer, um unsere eigenen Schneideparameter und Einstellungen anzupassen. Bambu Studio folgt dem gleichen Prinzip und verwendet maschinelles Lernen, um seine Leistung aus den Erfolgen und Fehlern der Vielzahl von Drucken unserer Benutzer zu verbessern. Wir trainieren Bambu Studio, indem wir ihnen reale Daten aus der Welt zur Verfügung stellen. Wenn Sie dies wünschen, greift dieser Service auf Informationen aus Ihren Fehler- und Nutzungsprotokollen zu, die Informationen enthalten können, die in der ",
		"t55": "Datenschutzrichtlinie",
		"t56": ". Wir werden keine personenbezogenen Daten erheben, durch die eine Person direkt oder indirekt identifiziert werden kann, einschließlich, aber nicht beschränkt auf Namen, Adressen, Zahlungsinformationen oder Telefonnummern. Durch Aktivieren dieses Dienstes stimmen Sie diesen Bedingungen und der Erklärung zur Datenschutzrichtlinie zu.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "Nordamerika",
		"t62": "Andere",
		"t63": "Nach Änderung der Region wird Ihr Konto abgemeldet. Bitte melden Sie sich später wieder an.",
		"t64": "Bambu Network-Plug-In",
		"t65": "Senden von Druckaufgaben über WLAN oder Cloud Service",
		"t66": "Vollständige Fernsteuerung",
		"t67": "Liveview-Streaming und Druckerstatusüberwachung",
		"t68": "Cloud-Synchronisierung für die Schneidkonfiguration",
		"t69": "Installieren Sie das Bambu Network-Plug-In",
		"t70": "",
		"t71": "Herunterladen",
		"t72": "Herunterladen fehlgeschlagen",
		"t73": "Installation erfolgreich.",
		"t74": "Neustart",
		"t75": "Das Bambu Network-Plug-In bietet folgende Funktionen:",
		"t76": "Bitte ",
		"t77": "installieren",
		"t78": " Sie das Netzwerk-Plugin, bevor Sie sich anmelden",
		"t79": "Installation des Plug-Ins fehlgeschlagen. ",
		"t80": "Versuchen Sie folgende Schritte:",
		"t81": "1, Klicken Sie ",
		"t82": "um das Plug-In-Verzeichnis zu öffnen",
		"t83": "2, Schließen Sie alle geöffneten Bambu Studio",
		"t84": "3, Löschen Sie alle Dateien im Plug-In-Verzeichnis",
		"t85": "4, Öffnen Sie Bambu Studio erneut und installieren Sie das Plug-In erneut",
		"t86": "Schließen",
		"t87": "Benutzerhandbuch",
		"t88": "Entfernen",
		"t89": "Enthaltenden Ordner öffnen",
		"t90": "3D-Modell",
		"t91": "3D-Modelle herunterladen",
		"t92": "Erstellt von",
		"t93": "Remixed von",
		"t94": "Geteilt von",
		"t95": "Modellinformationen",
		"t96": "Zubehör",
		"t97": "Profilinformationen",
		"t98": "Modellname",
		"t100": "Modellbeschreibung",
		"t101": "Stückliste",
		"t102": "Montageanleitung",
		"t103": "Andere",
		"t104": "Profilname",
		"t105": "Profilautor",
		"t106": "Profilbeschreibung",
		"t107": "Online-Modelle",
		"t108": "mehr",
		"t109": "System-Filamente",
		"t110": "Benutzerdefinierte Filamente",
		"t111": "Neu erstellen",
		"t112": "Teilnahme am Programm",
		"t113": "Sie können Ihre Wahl jederzeit ändern.",
		"t114": "Bibliothek",
		"t115": "Charge",
		"t116": "Erneut versuchen",
		"t117": "Druckverlauf",
		"t118": "Wird gedruckt",
		"t119": "Erfolg",
		"t120": "storniert",
		"t121": "Suche",
		"t122": "Suche Online-Modelle",
		"t123": "Teller",
		"t124": "",
		"t126": "Laden……",
		"wk17": "Bambu Lab Akademie",
		"wk18": "Schnellstartanleitung",
		"wk19": "Lernen nach Thema",
		"wk20": "Filament-Leitfaden",
		"wk21": "Jetzt erkunden"
	},
	"hu_HU": {
		"t1": "Üdvözöljük a Bambu Stúdióban",
		"t2": "A Bambu Stúdiót több lépésben állítjuk be. Kezdjük!",
		"t3": "Felhasználási feltételek",
		"t4": "Nem értek egyet",
		"t5": "Egyetértek",
		"t6": "Kérem, segítsen nekünk a nyomtatás minőségének javításában Mindenkinek jó lesz. Jöjjön és csatlakozzon az ügyfélélélmény fejlesztési programhoz",
		"t7": "Csatlakozzon az Ügyfélmegelégedettség javítási programunkhoz",
		"t8": "Vissza",
		"t9": "Tovább",
		"t10": "Nyomtató kiválasztása",
		"t11": "Összes",
		"t12": "Összes törlése",
		"t13": "mm fej",
		"t14": "Filament kiválasztása",
		"t15": "Nyomtató",
		"t16": "Filament típus",
		"t17": "Eladó",
		"t18": "hiba",
		"t19": "Legalább egy filamentet ki kell választani.",
		"t20": "Szeretné használni az alapértelmezett filamentet?",
		"t21": "igen",
		"t22": "nem",
		"t23": "Változások",
		"t24": "Indítás",
		"t25": "Befejez",
		"t26": "Bejelentkezés",
		"t27": "Regisztráció",
		"t28": "Modellek",
		"t29": "Áruház",
		"t30": "Kézikönyv",
		"t31": "Új projekt",
		"t32": "Új projekt létrehozása",
		"t33": "Projekt megnyitása",
		"t34": "hotspot",
		"t35": "Legutóbb megnyitott",
		"t36": "ok",
		"t37": "Legalább egy nyomtatót ki kell választani.",
		"t38": "Mégse",
		"t39": "Megerősít",
		"t40": "Hálózati kapcsolat megszakadt, kérjük ellenőrizze és próbálja meg később.",
		"t47": "Kérem, válassza ki a bejelentkezési régióját",
		"t48": "Ázsiai-csendes-óceáni térség",
		"t49": "Kínai szárazföld",
		"t50": "Kijelentkezés",
		"t52": "Kihagy",
		"t53": "Csatlakozás",
		"t54": "A 3D nyomtatási közösségben tanulunk egymás sikeréből és kudarcából, hogy a saját szeletelési paramétereinket és beállításainkat igazítsuk. A Bambu Studio ugyanezt az elvet követi, és gépi tanulást alkalmaz a felhasználóink által készített széles körű nyomatok sikerének és kudarcainak alapján. Azáltal, hogy a valódi világ adatait tápláljuk, okosabbá tanítjuk a Bambu Studiot. Ha hajlandó vagy, ez a szolgáltatás hozzáférhet az összes hibajegyzékéhez és használati naplójához, amelyek magukban foglalhatják a következő információkat: ",
		"t55": "Adatvédelmi irányelvek",
		"t56": ". Nem gyűjtünk olyan személyes adatokat, amelyekkel az egyént közvetlenül vagy közvetve lehet azonosítani, ideértve többek között a neveket, címeket, fizetési információkat vagy telefonszámokat. Az e szolgáltatás engedélyezésével elfogadja ezeket a feltételeket és az adatvédelmi irányelvekre vonatkozó nyilatkozatot.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Európa",
		"t61": "Észak-Amerika",
		"t62": "Egyéb",
		"t63": "A régió megváltoztatása után ki lesz jelentkezve a fiókodból. Kérjük, jelentkezzen be újra később.",
		"t64": "Bambu Network plug-in",
		"t65": "Nyomtatási feladat küldése WLAN vagy felhőszolgáltatáson keresztül",
		"t66": "Teljes távvezérlés",
		"t67": "Liveview-közvetítés és nyomtató állapotmonitorozás",
		"t68": "Félezési konfiguráció felhőszinkronizációja",
		"t69": "Bambu Network plug-in telepítése",
		"t70": "",
		"t71": "Letöltés",
		"t72": "Letöltés sikertelen",
		"t73": "Telepítés sikeres.",
		"t74": "Újraindítás",
		"t75": "A Bambu Network plug-in a következő funkciókat biztosítja:",
		"t76": "Jelentkezés előtt ",
		"t77": "telepítse",
		"t78": " a hálózati bővítményt",
		"t79": "Nem sikerült telepíteni a plug-int. ",
		"t80": "Próbálja meg az alábbi lépéseket:",
		"t81": "1, Kattintson ",
		"t82": " a plug-in könyvtár megnyitásához",
		"t83": "2, Zárja be az összes nyitott Bambu Studio-t",
		"t84": "3, Törölje az összes fájlt a plug-in könyvtárból",
		"t85": "4, Nyissa meg újra a Bambu studiót és telepítse újra a plug-int",
		"t86": "Bezárás",
		"t87": "Felhasználói kézikönyv",
		"t88": "Eltávolítás",
		"t89": "Tartalmazó mappa megnyitása",
		"t90": "3D model",
		"t91": "3D modellek letöltése",
		"t92": "Készítő",
		"t93": "Átdolgozó",
		"t94": "Megosztotta",
		"t95": "Model információ",
		"t96": "Kiegészítők",
		"t97": "Profil információ",
		"t98": "Modell név",
		"t100": "Modell leírás",
		"t101": "BOM",
		"t102": "Összeszerelési útmutató",
		"t103": "Egyéb",
		"t104": "Profil név",
		"t105": "Profil szerző",
		"t106": "Profil leírás",
		"t107": "Online modellek",
		"t108": "több",
		"t109": "Rendszer Filamentek",
		"t110": "Egyedi Filamentek",
		"t111": "Új Létrehozása",
		"t112": "Csatlakozás a programhoz",
		"t113": "Bármikor megváltoztathatja a preferenciáját.",
		"t114": "Könyvtár",
		"t115": "Tétel",
		"t116": "Újrapróbálkozás",
		"t117": "Nyomtatási előzmények",
		"t118": "Nyomtatás folyamatban",
		"t119": "Siker",
		"t120": "törölt",
		"t121": "Keresés",
		"t122": "Online modellek keresése",
		"t123": "tányér",
		"t124": "",
		"t126": "Betöltés folyamatban……",
		"wk17": "Bambu Lab Akadémia",
		"wk18": "Gyorsindítási Útmutató",
		"wk19": "Tanulj témakörök szerint",
		"wk20": "Filament Útmutató",
		"wk21": "Fedezd fel most"
	},
	"es_ES": {
		"t1": "Bienvenido a Bambu Studio",
		"t2": "Bambu Studio se configurará en varios pasos. ¡Comencemos!",
		"t3": "Acuerdo de usuario",
		"t4": "No estoy de acuerdo",
		"t5": "Estoy de acuerdo",
		"t6": "Le pedimos amablemente su ayuda para mejorar la impresión de todos. Bienvenido a nuestro programa de mejora de la experiencia del cliente",
		"t7": "Únase a nuestro Programa de Mejora de la Experiencia del Cliente",
		"t8": "Volver",
		"t9": "Siguiente",
		"t10": "Selección de impresora",
		"t11": "Todo",
		"t12": "Borrar todo",
		"t13": "Boquilla de mm",
		"t14": "Selección de filamento",
		"t15": "Impresora",
		"t16": "Tipo de filamento",
		"t17": "Proveedor",
		"t18": "Error",
		"t19": "Debe seleccionar al menos un filamento.",
		"t20": "¿Desea utilizar el filamento predeterminado?",
		"t21": "sí",
		"t22": "no",
		"t23": "Notas de lanzamiento",
		"t24": "Empezar",
		"t25": "Terminar",
		"t26": "Iniciar sesión",
		"t27": "Registrarse",
		"t28": "Modelli",
		"t29": "Centro comercial",
		"t30": "Manual",
		"t31": "Nuevo proyecto",
		"t32": "Crear nuevo proyecto",
		"t33": "Abrir proyecto",
		"t34": "punto de acceso",
		"t35": "Recientemente abierto",
		"t36": "Aceptar",
		"t37": "Debe seleccionar al menos una impresora.",
		"t38": "Cancelar",
		"t39": "Confirmar",
		"t40": "Desconexión de red, por favor verifique e intente nuevamente más tarde.",
		"t47": "Seleccione su región de inicio de sesión",
		"t48": "Asia-Pacífico",
		"t49": "China continental",
		"t50": "Cerrar sesión",
		"t52": "Saltar",
		"t53": "Unirse",
		"t54": "En la comunidad de impresión 3D, aprendemos de los éxitos y fracasos de los demás para ajustar nuestros propios parámetros y configuraciones de corte. Bambu Studio sigue el mismo principio y utiliza el aprendizaje automático para mejorar su rendimiento a partir de los éxitos y fracasos de la gran cantidad de impresiones de nuestros usuarios. Estamos entrenando a Bambu Studio para que sea más inteligente alimentándolos con datos del mundo real. Si lo desea, este servicio accederá a la información de sus registros de errores y registros de uso, que pueden incluir información descrita en ",
		"t55": "Política de privacidad",
		"t56": ". No recopilaremos ningún dato personal por el cual se pueda identificar a un individuo directa o indirectamente, incluyendo sin limitación nombres, direcciones, información de pago o números de teléfono. Al habilitar este servicio, acepta estos términos y la declaración sobre la política de privacidad.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "Norteamérica",
		"t62": "Otros",
		"t63": "Después de cambiar la región, se cerrará la sesión de su cuenta. Por favor, vuelva a iniciar sesión más tarde.",
		"t64": "Complemento de red de Bambu",
		"t65": "Envío de trabajo de impresión a través de WLAN o servicio en la nube",
		"t66": "Control remoto completo",
		"t67": "Streaming de Liveview y monitorización del estado de la impresora",
		"t68": "Sincronización en la nube para la configuración de rebanado",
		"t69": "Instalar complemento de red de Bambu",
		"t70": "",
		"t71": "Descargando",
		"t72": "Error al descargar",
		"t73": "Instalación exitosa.",
		"t74": "Reiniciar",
		"t75": "El complemento de red de Bambu proporciona las siguientes características:",
		"t76": "Por favor,",
		"t77": "instala",
		"t78": " el complemento de red antes de iniciar sesión",
		"t79": "Error al instalar el complemento. ",
		"t80": "Intente los siguientes pasos:",
		"t81": "1, Haga clic en ",
		"t82": " para abrir el directorio del complemento",
		"t83": "2, Cierre todas las instancias de Bambu Studio abiertas",
		"t84": "3, Elimine todos los archivos en el directorio del complemento",
		"t85": "4, Abra de nuevo Bambu Studio e instale el complemento de nuevo",
		"t86": "Cerrar",
		"t87": "Manual de usuario",
		"t88": "Eliminar",
		"t89": "Abrir carpeta contenedora",
		"t90": "Modelo 3D",
		"t91": "Descargar modelos 3D",
		"t92": "Creado por",
		"t93": "Remixado por",
		"t94": "Compartido por",
		"t95": "Información del modelo",
		"t96": "Accesorios",
		"t97": "Información del perfil",
		"t98": "Nombre del modelo",
		"t100": "Descripción del modelo",
		"t101": "Lista de materiales",
		"t102": "Guía de ensamblaje",
		"t103": "Otros",
		"t104": "Nombre del perfil",
		"t105": "Autor del perfil",
		"t106": "Descripción del perfil",
		"t107": "Modelos en línea",
		"t108": "más",
		"t109": "Filamenti di Sistema",
		"t110": "Filamenti Personalizzati",
		"t111": "Crea Nuovo",
		"t112": "Unirse al programa",
		"t113": "Puede cambiar sus preferencias en cualquier momento.",
		"t114": "Biblioteca",
		"t115": "Un lote",
		"t116": "Reintentar",
		"t117": "Historial de impresión",
		"t118": "Imprimiendo",
		"t119": "Éxito",
		"t120": "cancelado",
		"t121": "Búsqueda",
		"t122": "Buscar modelos en línea",
		"t123": "plato",
		"t124": "",
		"t126": "Carga en progreso……",
		"wk17": "Academia Bambu Lab",
		"wk18": "Tutorial de Inicio Rápido",
		"wk19": "Aprender por tema",
		"wk20": "Guía de filamentos",
		"wk21": "Explorar ahora"
	},
	"sv_SE": {
		"t1": "Välkommen till Bambu Studio",
		"t2": "Bambu Studio kommer att ställas in i flera steg. Låt oss börja!",
		"t3": "Användaravtal",
		"t4": "Oenig",
		"t5": "Enig",
		"t6": "Vi ber om din hjälp för att förbättra allas utskrifter. Kom och gå med i vårt program för förbättring av kundupplevelsen",
		"t7": "Gå med i vårt Customer Experience Improvement Program",
		"t8": "Tillbaka",
		"t9": "Nästa",
		"t10": "Skrivarselection",
		"t11": "Allt",
		"t12": "Rensa alla",
		"t13": "mm munstycke",
		"t14": "Filamentselection",
		"t15": "Skrivare",
		"t16": "Filamenttyp",
		"t17": "Leverantör",
		"t18": "Fel",
		"t19": "Minst ett filament måste väljas.",
		"t20": "Vill du använda standardfilament?",
		"t21": "ja",
		"t22": "nej",
		"t23": "Versionsnotering",
		"t24": "Kom igång",
		"t25": "Slutföra",
		"t26": "Logga in",
		"t27": "Registrera dig",
		"t28": "Modeller",
		"t29": "Mall",
		"t30": "Manual",
		"t31": "Nytt projekt",
		"t32": "Skapa nytt projekt",
		"t33": "Öppet projekt",
		"t34": "hotspot",
		"t35": "Nyligen öppnad",
		"t36": "okej",
		"t37": "Minst en skrivare måste väljas.",
		"t38": "Avbryt",
		"t39": "Bekräfta",
		"t40": "Nätverket är frånkopplat, vänligen kontrollera och försök igen senare.",
		"t47": "Vänligen välj din inloggningsregion",
		"t48": "Asien och Stillahavsområdet",
		"t49": "Kinesiska fastlandet",
		"t50": "Logga ut",
		"t52": "Hoppa över",
		"t53": "Gå med",
		"t54": "I 3D-utskriftssamhället lär vi oss av varandras framgångar och misslyckanden för att justera våra egna skivparametrar och inställningar. Bambu Studio följer samma princip och använder maskininlärning för att förbättra sin prestanda från användarnas stora antal utskrifters framgångar och misslyckanden. Vi tränar Bambu Studio att bli smartare genom att mata dem med verkliga data. Om du är villig kommer denna tjänst att få åtkomst till information från dina felloggar och användningsloggar, som kan innehålla information som beskrivs i",
		"t55": "Integritetspolicy",
		"t56": ". Vi kommer inte att samla in några personuppgifter genom vilka en individ kan identifieras direkt eller indirekt, inklusive namn, adresser, betalningsinformation eller telefonnummer. Genom att aktivera denna tjänst samtycker du till dessa villkor och uttalandet om integritetspolicy.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "Nordamerika",
		"t62": "Andra",
		"t63": "Efter att ha ändrat regionen kommer ditt konto att loggas ut. Logga in igen senare.",
		"t64": "Bambu Network plug-in",
		"t65": "Skicka utskriftsjobb via WLAN eller molntjänst",
		"t66": "Fullständig fjärrstyrning",
		"t67": "Liveview-strömning och statusövervakning av skrivaren",
		"t68": "Molnsynkronisering för skärkonfiguration",
		"t69": "Installera Bambu Network plug-in",
		"t70": "",
		"t71": "Laddar ner",
		"t72": "Nedladdning misslyckades",
		"t73": "Installation lyckad.",
		"t74": "Starta om",
		"t75": "Bambu Network plug-in tillhandahåller följande funktioner:",
		"t76": "",
		"t77": "Installera",
		"t78": "nätverksinsticksprogrammet innan du loggar in",
		"t79": "Misslyckades med att installera tillägget. ",
		"t80": "Försök följande steg:",
		"t81": "1, Klicka ",
		"t82": " för att öppna tilläggsbiblioteket",
		"t83": "2, Stäng alla öppna Bambu Studio",
		"t84": "3, Radera alla filer under tilläggsbiblioteket",
		"t85": "4, Öppna Bambu Studio igen och installera tillägget på nytt",
		"t86": "Stäng",
		"t87": "Användarmanual",
		"t88": "Ta bort",
		"t89": "Öppna innehållsförteckning",
		"t90": "3D-modell",
		"t91": "Ladda ner 3D-modeller",
		"t92": "Skapad av",
		"t93": "Remixad av",
		"t94": "Delad av",
		"t95": "Modellinformation",
		"t96": "Tillbehör",
		"t97": "Profileringsinformation",
		"t98": "Modellnamn",
		"t100": "Modellbeskrivning",
		"t101": "BOM",
		"t102": "Monteringsguide",
		"t103": "Övrigt",
		"t104": "Profilnamn",
		"t105": "Profilförfattare",
		"t106": "Profilsbeskrivning",
		"t107": "Online-modeller",
		"t108": "mer",
		"t109": "Systemfilament",
		"t110": "Anpassade filament",
		"t111": "Skapa ny",
		"t112": "Gå med i programmet",
		"t113": "Du kan ändra ditt val när som helst.",
		"t114": "Bibliotek",
		"t115": "Batch",
		"t116": "Försök igen",
		"t117": "Utskriftshistorik",
		"t118": "Skrivs ut",
		"t119": "Lyckad",
		"t120": "avbruten",
		"t121": "Sök",
		"t122": "Sök online-modeller",
		"t123": "fat",
		"t124": "",
		"t126": "Laddning pågår……",
		"wk17": "Bambu Lab Akademin",
		"wk18": "Snabbstartsguide",
		"wk19": "Lär dig efter ämne",
		"wk20": "Filamentguide",
		"wk21": "Utforska nu"
	},
	"cs_CZ": {
		"t1": "Vítejte v Bambu Studio",
		"t2": "Bambu Studio bude nastaveno několika kroky. Začněme!",
		"t3": "Uživatelská dohoda",
		"t4": "Nesouhlasím",
		"t5": "Souhlasím",
		"t6": "Vřele žádáme o vaši pomoc pro zlepšení tisku pro všechny. Přijďte a připojte se k našemu programu zlepšování zkušeností zákazníků",
		"t7": "Zapojte se do našeho programu pro zlepšení zákaznického zážitku",
		"t8": "Zpět",
		"t9": "Dále",
		"t10": "Výběr tiskárny",
		"t11": "Všechny",
		"t12": "Zrušit výběr",
		"t13": "mm tryska",
		"t14": "Výběr filamentu",
		"t15": "Tiskárna",
		"t16": "Typ filamentu",
		"t17": "Výrobce",
		"t18": "chyba",
		"t19": "Je nutné vybrat minimálně jeden filament.",
		"t20": "Chcete použít výchozí filament?",
		"t21": "ano",
		"t22": "ne",
		"t23": "Poznámka k vydání",
		"t24": "Začít",
		"t25": "Dokončit",
		"t26": "Přihlásit se",
		"t27": "Registrovat",
		"t28": "Nedávno",
		"t29": "Obchod",
		"t30": "Nápověda",
		"t31": "Nový projekt",
		"t32": "Vytvořit nový projekt",
		"t33": "Otevřít projekt",
		"t34": "Hotspot",
		"t35": "Nedávno otevřené",
		"t36": "OK",
		"t37": "Je nutné vybrat minimálně jednu tiskárnu.",
		"t38": "Zrušit",
		"t39": "Potvrdit",
		"t40": "Odpojení od sítě, prosím zkontrolujte a zkuste to později znovu.",
		"t47": "Vyberte prosím svou přihlašovací oblast",
		"t48": "Asie-Pacifik",
		"t49": "Čínská pevninská",
		"t50": "Odhlásit se",
		"t52": "Přeskočit",
		"t53": "Připojit",
		"t54": "Ve společenství 3D tisku se učíme ze zkušeností druhých a z jejich neúspěchů, abychom upravili naše vlastní parametry a nastavení tisku. Bambu Studio následuje stejný princip a pomocí strojového učení zlepšuje svou výkonnost na základě úspěchů a selhání velkého množství tisků našich uživatelů. Trénujeme Bambu Studio, aby bylo chytřejší tím, že jim předáváme reálná data. Pokud jste ochotní, tato služba bude mít přístup k informacím z vašich chybových protokolů a protokolů o používání, které mohou obsahovat informace popsané v ",
		"t55": "Zásady ochrany osobních údajů",
		"t56": ". Nezískáváme žádné osobní údaje, pomocí kterých by bylo možné identifikovat osobu přímo nebo nepřímo, včetně, ale neomezeně na jména, adresy, platební údaje nebo telefonní čísla. Aktivací této služby souhlasíte s těmito podmínkami a prohlášením o zásadách ochrany osobních údajů.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Evropa",
		"t61": "Severní Amerika",
		"t62": "Ostatní",
		"t63": "Po změně regionu bude váš účet odhlášen. Prosím přihlašte se znovu později.",
		"t64": "Zásuvný modul Bambu Network",
		"t65": "Odesílání tiskové úlohy přes WLAN nebo cloudovou službu",
		"t66": "Plná vzdálená kontrola",
		"t67": "Streamování Liveview a sledování stavu tiskárny",
		"t68": "Cloudová synchronizace konfigurace řezání",
		"t69": "Instalovat zásuvný modul Bambu Network",
		"t70": "",
		"t71": "Stahování",
		"t72": "Stahování selhalo",
		"t73": "Instalace úspěšná.",
		"t74": "Restart",
		"t75": "Zásuvný modul Bambu Network poskytuje následující funkce:",
		"t76": "Před přihlášením ",
		"t77": "nainstalujte",
		"t78": " síťový plugin",
		"t79": "Instalace zásuvného modulu selhala. ",
		"t80": "Zkuste následující kroky:",
		"t81": "1, Klikněte ",
		"t82": " pro otevření adresáře s zásuvnými moduly",
		"t83": "2, Zavřete všechny otevřené instance Bambu Studio",
		"t84": "3, Smažte všechny soubory ve složce se zásuvnými moduly",
		"t85": "4, Znovu spusťte Bambu Studio a zásuvný modul znovu nainstalujte",
		"t86": "Zavřít",
		"t87": "Uživatelský manuál",
		"t88": "Odebrat",
		"t89": "Otevřít složku obsahující soubory",
		"t90": "3D Model",
		"t91": "Stáhnout 3D modely",
		"t92": "Vytvořil",
		"t93": "Přepracováno",
		"t94": "Sdíleno",
		"t95": "Informace o modelu",
		"t96": "Příslušenství",
		"t97": "Informace o profilu",
		"t98": "Název modelu",
		"t100": "Popis modelu",
		"t101": "Seznam součástek (BOM)",
		"t102": "Průvodce sestavením",
		"t103": "Jiné",
		"t104": "Název profilu",
		"t105": "Autor profilu",
		"t106": "Popis profilu",
		"t107": "Online modely",
		"t108": "více",
		"t109": "Systémové materiály",
		"t110": "Samostatné materiály",
		"t111": "Nové",
		"t112": "Připojte se k programu",
		"t113": "Své preference můžete kdykoliv změnit.",
		"t114": "Knihovna",
		"t115": "Šarže",
		"t116": "Zkuste to znovu",
		"t117": "Historie tisku",
		"t118": "Tisk probíhá",
		"t119": "Úspěch",
		"t120": "zrušený",
		"t121": "Hledat",
		"t122": "Hledat online modely",
		"t123": "talíř",
		"t124": "",
		"t126": "Načtení probíhá……",
		"wk17": "Bambu Lab Akademie",
		"wk18": "Rychlý Návod k Použití",
		"wk19": "Učit se podle tématu",
		"wk20": "Průvodce filamenty",
		"wk21": "Prozkoumat nyní"
	},
	"nl_NL": {
		"t1": "Welkom bij Bambu Studio",
		"t2": "Bambu Studio wordt in verschillende stappen opgezet. Laten we beginnen!",
		"t3": "Gebruikersovereenkomst",
		"t4": "Oneens",
		"t5": "Akkoord",
		"t6": "We vragen vriendelijk uw hulp om de printervaring van iedereen te verbeteren. Kom en doe mee met ons programma voor verbetering van de klantervaring",
		"t7": "Doe mee aan ons programma voor het verbeteren van de klantervaring",
		"t8": "Terug",
		"t9": "Volgende",
		"t10": "Printerselectie",
		"t11": "Alle",
		"t12": "Alles wissen",
		"t13": "mm mondstuk",
		"t14": "Filamentselectie",
		"t15": "Printer",
		"t16": "Filamenttype",
		"t17": "Leverancier",
		"t18": "Fout",
		"t19": "Er moet ten minste één filament worden geselecteerd.",
		"t20": "Wilt u het standaard filament gebruiken?",
		"t21": "ja",
		"t22": "nee",
		"t23": "Release-opmerking",
		"t24": "Aan de slag",
		"t25": "Voltooien",
		"t26": "Inloggen",
		"t27": "Registreren",
		"t28": "Modellen",
		"t29": "Winkelcentrum",
		"t30": "Handleiding",
		"t31": "Nieuw project",
		"t32": "Nieuw project maken",
		"t33": "Project openen",
		"t34": "hotspot",
		"t35": "Recent geopend",
		"t36": "Oké",
		"t37": "Er moet ten minste één printer worden geselecteerd.",
		"t38": "Annuleren",
		"t39": "Bevestigen",
		"t40": "Netwerkverbinding verbroken, controleer en probeer het later opnieuw.",
		"t47": "Selecteer uw login-regio",
		"t48": "Azië-Pacific",
		"t49": "Chinees vasteland",
		"t50": "Uitloggen",
		"t52": "Overslaan",
		"t53": "Deelnemen",
		"t54": "In de 3D-printgemeenschap leren we van elkaars successen en mislukkingen om onze eigen sliceparameters en instellingen aan te passen. Bambu Studio volgt hetzelfde principe en gebruikt machine learning om zijn prestaties te verbeteren op basis van de successen en mislukkingen van de grote hoeveelheid prints door onze gebruikers. We trainen Bambu Studio om slimmer te worden door hen echte gegevens te voeden. Als u bereid bent, heeft deze service toegang tot informatie uit uw fouten- en gebruiklogs, die informatie kunnen bevatten zoals beschreven in",
		"t55": "Privacy Policy",
		"t56": ". We zullen geen Persoonlijke Gegevens verzamelen waarmee een individu direct of indirect kan worden geïdentificeerd, inclusief maar niet beperkt tot namen, adressen, betalingsinformatie of telefoonnummers. Door deze service in te schakelen, gaat u akkoord met deze voorwaarden en de verklaring over het privacybeleid.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "Noord-Amerika",
		"t62": "Andere",
		"t63": "Na het wijzigen van de regio wordt uw account uitgelogd. Log later opnieuw in.",
		"t64": "Bambu Network-plug-in",
		"t65": "Afdruktaak verzenden via WLAN of cloud service",
		"t66": "Volledige externe bediening",
		"t67": "Liveview-streaming en printerstatusmonitoring",
		"t68": "Cloudsynchronisatie voor slicingconfiguratie",
		"t69": "Bambu Network-plug-in installeren",
		"t70": "",
		"t71": "Downloaden",
		"t72": "Downloaden mislukt",
		"t73": "Installatie succesvol.",
		"t74": "Herstart",
		"t75": "Bambu Network-plug-in biedt de volgende functies:",
		"t76": "",
		"t77": "Installeer",
		"t78": " de netwerkplug-in voordat u inlogt",
		"t79": "Installatie van de plug-in mislukt. ",
		"t80": "Probeer de volgende stappen:",
		"t81": "1, Klik ",
		"t82": "om de plug-in directory te openen",
		"t83": "2, Sluit alle openstaande Bambu Studio's",
		"t84": "3, Verwijder alle bestanden in de plug-in directory",
		"t85": "4, Open Bambu studio opnieuw en installeer de plug-in opnieuw",
		"t86": "Sluiten",
		"t87": "Gebruikershandleiding",
		"t88": "Verwijderen",
		"t89": "Map openen",
		"t90": "3D-model",
		"t91": "3D-modellen downloaden",
		"t92": "Gemaakt door",
		"t93": "Geremixed door",
		"t94": "Gedeeld door",
		"t95": "Modelinformatie",
		"t96": "Accessoires",
		"t97": "Profielinformatie",
		"t98": "Modelnaam",
		"t100": "Modelbeschrijving",
		"t101": "BOM",
		"t102": "Montagehandleiding",
		"t103": "Overige",
		"t104": "Profielnaam",
		"t105": "Profielauteur",
		"t106": "Profielbeschrijving",
		"t107": "Online modellen",
		"t108": "meer",
		"t109": "Systeemfilamenten",
		"t110": "Aangepaste filamenten",
		"t111": "Nieuw maken",
		"t112": "Deelnemen aan het programma",
		"t113": "U kunt uw keuze op elk gewenst moment wijzigen.",
		"t114": "Bibliotheek",
		"t115": "Batch",
		"t116": "Probeer het opnieuw",
		"t117": "Afdrukhistoriek",
		"t118": "Aan het printen",
		"t119": "Succes",
		"t120": "geannuleerd",
		"t121": "Zoeken",
		"t122": "Zoek online modellen",
		"t123": "bord",
		"t124": "",
		"t126": "Laden in uitvoering……",
		"wk17": "Bambu Lab Academie",
		"wk18": "Snelstartgids",
		"wk19": "Leren per Onderwerp",
		"wk20": "Filamentgids",
		"wk21": "Nu verkennen"
	},
	"uk_UA": {
		"t1": "Вітаємо в Bambu Studio!",
		"t2": "Для налаштування Bambu Studio необхідно пройти кілька етапів. Почнімо!",
		"t3": "Угода користувача",
		"t4": "Відмовитися",
		"t5": "Прийняти",
		"t6": "Ми просимо вашої допомоги, щоб покращити друк. Ласкаво просимо до нашої програми підвищення якості обслуговування клієнтів",
		"t7": "Дозволити відправку анонімних даних для удосконалення програми",
		"t8": "Назад",
		"t9": "Далі",
		"t10": "Вибір принтера",
		"t11": "Всі",
		"t12": "Очистити",
		"t13": "мм сопло",
		"t14": "Вибір пластикової нитки",
		"t15": "Принтер",
		"t16": "Тип стрижня",
		"t17": "Виробник",
		"t18": "помилка",
		"t19": "Має бути вибрана принаймні одна пластикова нитка.",
		"t20": "Вибрати пластикові нитки за замовчуванням?",
		"t21": "так",
		"t22": "ні",
		"t23": "Інформація про версію",
		"t24": "Почати",
		"t25": "Закінчити",
		"t26": "Увійти",
		"t27": "Реєстрація",
		"t28": "Моделі",
		"t29": "Mall",
		"t30": "Інструкції",
		"t31": "Новий проєкт",
		"t32": "Створити новий проєкт",
		"t33": "Відкрити проєкт",
		"t34": "точка доступу",
		"t35": "Нещодавно відкриті",
		"t36": "ОК",
		"t37": "Має бути вибраний принаймні один принтер.",
		"t38": "Скасувати",
		"t39": "Прийняти",
		"t40": "Мережа відключена. Будь ласка, перевірте з'єднання та спробуйте знову.",
		"t47": "Будь ласка, виберіть регіон входу",
		"t48": "Азійсько-Тихоокеанський регіон",
		"t49": "Материковый Китай",
		"t50": "Вийти",
		"t52": "Пропустити",
		"t53": "Увійти",
		"t54": "У спільноті 3D-друкарів для виявлення найкращих параметрів нарізки та покращення друку ми вчимося на успіхах та невдачах один одного. Bambu Studio слідує тому ж принципу і використовує машинне навчання для покращення своєї роботи на основі успішних та невдалих друків наших користувачів. Ми навчаємо Bambu Studio бути розумнішим на основі реальних даних. За вашою згодою ця служба отримає доступ до ваших журналів помилок та журналів використання, в яких містяться дані, описані в ",
		"t55": "політиці конфіденційності",
		"t56": ". Ми не збираємо жодних особистих даних, які можуть безпосередньо або побічно ідентифікувати окрему особу, включно, серед іншого, з іменами, адресами, платіжною інформацією або телефонними номерами. Погоджуючись на включення даної служби, ви погоджуєтеся з цими умовами та заявою про політику конфіденційності.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Європа",
		"t61": "Північна Америка",
		"t62": "Інший",
		"t63": "Після зміни регіону відбудеться вихід з акаунта. Будь ласка, увійдіть пізніше.",
		"t64": "Мережевий плагін Bambu",
		"t65": "Відправка завдань друку через WLAN або хмарну службу",
		"t66": "Повне дистанційне керування",
		"t67": "Стрімінг Liveview та моніторинг стану принтера",
		"t68": "Хмарна синхронізація конфігурації різання",
		"t69": "Встановити мережевий плагін Bambu",
		"t70": "",
		"t71": "Завантаження",
		"t72": "Завантаження не вдалося",
		"t73": "Встановлення виконано успішно.",
		"t74": "Перезавантаження",
		"t75": "Мережевий плагін Bambu надає наступні можливості:",
		"t76": "",
		"t77": "Встановіть",
		"t78": " мережевий плагін перед входом",
		"t79": "Помилка встановлення плагіна. ",
		"t80": "Спробуйте виконати наступні дії:",
		"t81": "1, Натисніть ",
		"t82": " щоб відкрити папку плагінів",
		"t83": "2, Закрийте всі відкриті Bambu Studio",
		"t84": "3, Видаліть всі файли у папці плагіна",
		"t85": "4, Відкрийте Bambu studio та знову встановіть підключуваний модуль.",
		"t86": "Закрити",
		"t87": "Інструкції",
		"t88": "Видалити",
		"t89": "Відкрити папку з вмістом",
		"t90": "3D-модель",
		"t91": "Завантажити 3D-моделі",
		"t92": "Автор",
		"t93": "Модифіковано",
		"t94": "Поділитися",
		"t95": "Інформація про модель",
		"t96": "Прикріплені файли",
		"t97": "Інформація про профіль",
		"t98": "Ім'я моделі",
		"t100": "Опис моделі",
		"t101": "Список матеріалів",
		"t102": "Пам'ятка зі збірки",
		"t103": "Інше",
		"t104": "Ім'я профілю",
		"t105": "Профіль автора",
		"t106": "Опис профілю",
		"t107": "Моделі в мережі",
		"t108": "Більше",
		"t109": "Системні філаменти",
		"t110": "Користувацькі філаменти",
		"t111": "Створити новий",
		"t112": "Приєднуйтеся до програми",
		"t113": "Ви можете змінити свої переваги в будь-який час.",
		"t114": "Бібліотека",
		"t115": "Одна партія",
		"t116": "Спробувати знову",
		"t117": "Історія друку",
		"t118": "Друкується",
		"t119": "Успіх",
		"t120": "скасований",
		"t121": "Пошук",
		"t122": "Пошук онлайн-моделей",
		"t123": "тарілка",
		"t124": "",
		"t126": "Завантаження триває……",
		"wk17": "Академія Bambu Lab",
		"wk18": "Керівництво з Швидкого Початку",
		"wk19": "Навчання за Темою",
		"wk20": "Посібник з Філаментів",
		"wk21": "Досліджуйте зараз"
	},
	"ru_RU": {
		"t1": "Приветствуем в Bambu Studio!",
		"t2": "Для настройка Bambu Studio необходимо пройти несколько этапов. Давайте начнём!",
		"t3": "Пользовательское соглашение",
		"t4": "Отказаться",
		"t5": "Принять",
		"t6": "Мы просим вашей помощи, чтобы улучшить печать. Добро пожаловать в нашу программу улучшения качества обслуживания клиентов",
		"t7": "Разрешить отправку анонимных данных для совершенствования программы",
		"t8": "Назад",
		"t9": "Далее",
		"t10": "Выбор принтера",
		"t11": "Все",
		"t12": "Очистить всё",
		"t13": "мм сопло",
		"t14": "Выбор пластиковой нити",
		"t15": "Принтер",
		"t16": "Тип прутка",
		"t17": "Производитель",
		"t18": "ошибка",
		"t19": "Должна быть выбрана хотя бы одна пластиковая нить.",
		"t20": "Выбрать пластиковые нити по умолчанию?",
		"t21": "да",
		"t22": "нет",
		"t23": "Информация о версии",
		"t24": "Начать",
		"t25": "Закончить",
		"t26": "Войти",
		"t27": "Регистрация",
		"t28": "Модели",
		"t29": "Mall",
		"t30": "Инструкции",
		"t31": "Новый проект",
		"t32": "Создать новый проект",
		"t33": "Открыть проект",
		"t34": "точка доступа",
		"t35": "Недавно открытые",
		"t36": "OK",
		"t37": "Должен быть выбран хотя бы один принтер.",
		"t38": "Отмена",
		"t39": "Принять",
		"t40": "Сеть отключена. Пожалуйста, проверьте подключение и попробуйте снова.",
		"t47": "Пожалуйста, выберите регион входа",
		"t48": "Азиатско-Тихоокеанский регион",
		"t49": "Материковый Китай",
		"t50": "Выйти",
		"t52": "Пропустить",
		"t53": "Войти",
		"t54": "В сообществе 3D-печатников для выявления наилучших параметров нарезки и улучшения печати мы учимся на успехах и неудачах друг друга. Bambu Studio следует тому же принципу и использует машинное обучение для улучшения своей работы на основе успешных и неудачных печатей наших пользователей. Мы обучаем Bambu Studio быть умнее на основе реальных данных. По вашему согласию эта служба получит доступ к вашим журналам ошибок и журналам использования, в которых содержатся сведения, описанные в ",
		"t55": "политике конфиденциальности",
		"t56": ". Мы не собираем никаких личных данных, которые могут прямо или косвенно идентифицировать отдельного человека, включая, помимо прочего, имена, адреса, платежную информацию или номера телефонов. Соглашаясь с включением данной службы, вы соглашаетесь с этими условиями и заявлением о политике конфиденциальности.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Европа",
		"t61": "Северная Америка",
		"t62": "Другой",
		"t63": "После смены региона произойдёт выход из аккаунта. Пожалуйста, войдите позже.",
		"t64": "Сетевой плагин Bambu",
		"t65": "Отправка задания на печать через WLAN или облаконную службу",
		"t66": "Полное дистанционное управление",
		"t67": "Стриминг Liveview и мониторинг состояния принтера",
		"t68": "Облачная синхронизация конфигурации среза",
		"t69": "Установить сетевой плагин Bambu",
		"t70": "",
		"t71": "Загрузка",
		"t72": "Загрузка не удалась",
		"t73": "Установка выполнена успешно.",
		"t74": "Перезагрузка",
		"t75": "Сетевой плагин Bambu предоставляет следующие возможности:",
		"t76": "Пожалуйста, ",
		"t77": "установите",
		"t78": " сетевой плагин перед входом в систему",
		"t79": "Ошибка установки плагина. ",
		"t80": "Попробуйте выполнить следующие действия:",
		"t81": "1, Нажмите ",
		"t82": " чтобы открыть папку плагинов",
		"t83": "2, Закрыть все открытые Bambu Studio",
		"t84": "3, Удалить все файлы в папке плагина",
		"t85": "4, Откройте Bambu studio и снова установите подключаемый модуль.",
		"t86": "Закрыть",
		"t87": "Инструкции",
		"t88": "Удалить",
		"t89": "Открыть папку с содержимым",
		"t90": "3D-модель",
		"t91": "Скачать 3D-модели",
		"t92": "Автор",
		"t93": "Модифицировано",
		"t94": "Поделиться",
		"t95": "Информация о модели",
		"t96": "Прикреплённые файлы",
		"t97": "Информация о профиле",
		"t98": "Имя модели",
		"t100": "Описание модели",
		"t101": "Список материалов",
		"t102": "Памятка по сборке",
		"t103": "Прочее",
		"t104": "Имя профиля",
		"t105": "Профиль автора",
		"t106": "Описание профиля",
		"t107": "Модели в сети",
		"t108": "Больше",
		"t109": "Системные прутки",
		"t110": "Пользовательские прутки",
		"t111": "Создать новый",
		"t112": "Присоединяйтесь к программе",
		"t113": "Вы можете изменить свои предпочтения в любое время.",
		"t114": "Библиотека",
		"t115": "Одна партия",
		"t116": "Повторить попытку",
		"t117": "История печати",
		"t118": "Печатается",
		"t119": "Успех",
		"t120": "отмененный",
		"t121": "Поиск",
		"t122": "Поиск онлайн-моделей",
		"t123": "тарелка",
		"t124": "",
		"t126": "Загрузка идёт……",
		"wk17": "Академия Bambu Lab",
		"wk18": "Руководство по быстрому запуску",
		"wk19": "Обучение по теме",
		"wk20": "Руководство по пруткам",
		"wk21": "Исследуйте сейчас"
	},
	"tr_TR": {
		"t1": "Bambu Stüdyo'ya Hoş Geldiniz",
		"t2": "Bambu Studio birkaç adımda kurulacaktır. Hadi başlayalım!",
		"t3": "Kullanıcı Sözleşmesi",
		"t4": "Reddet",
		"t5": "Onayla",
		"t6": "Herkesin baskısını iyileştirmek için yardımınızı rica ediyoruz.<br/>Gelin ve Müşteri Deneyimi İyileştirme Programımıza Katılın",
		"t7": "Anonim verilerin gönderilmesine izin ver",
		"t8": "Geri",
		"t9": "İleri",
		"t10": "Yazıcı Seçimi",
		"t11": "Hepsi",
		"t12": "Hepsini temizle",
		"t13": "mm nozul",
		"t14": "Filament Seçimi",
		"t15": "Yazıcı",
		"t16": "Filament türü",
		"t17": "Üretici",
		"t18": "hata",
		"t19": "En az bir filament seçilmelidir.",
		"t20": "Varsayılan filamenti kullanmak ister misiniz ?",
		"t21": "Evet",
		"t22": "Hayır",
		"t23": "Sürüm notu",
		"t24": "Başla",
		"t25": "Bitir",
		"t26": "Giriş Yap",
		"t27": "Kayıt Ol",
		"t28": "Modeller",
		"t29": "Mağaza",
		"t30": "Kılavuz",
		"t31": "Yeni proje",
		"t32": "Yeni proje oluştur",
		"t33": "Projeyi Aç",
		"t34": "Erişim noktası",
		"t35": "Yakın zamanda açıldı",
		"t36": "Tamam",
		"t37": "En az bir yazıcı seçilmelidir.",
		"t38": "İptal Et",
		"t39": "Onayla",
		"t40": "Ağ bağlantısı kesildi, lütfen kontrol edin ve daha sonra tekrar deneyin.",
		"t47": "Lütfen giriş bölgenizi seçin",
		"t48": "Asya-Pasifik",
		"t49": "Çin Mainland",
		"t50": "Çıkış Yap",
		"t52": "Atla",
		"t53": "Katıl",
		"t54": "3D Baskı topluluğunda, kendi dilimleme parametrelerimizi ve ayarlarımızı ayarlamak için birbirimizin başarılarından ve başarısızlıklarından öğreniyoruz. Bambu Studio da aynı prensibi izliyor ve kullanıcılarımız tarafından yapılan çok sayıda baskının başarı ve başarısızlıklarından performansını artırmak için makine öğrenimini kullanıyor. Bambu Studio'yu gerçek dünya verileriyle besleyerek daha akıllı olması için eğitiyoruz. İsterseniz, bu hizmet hata günlüklerinizden ve kullanım günlüklerinizden aşağıdaki bilgileri içerebilecek bilgilere erişecektir ",
		"t55": "Privacy Policy",
		"t56": ". Kişinin doğrudan veya dolaylı olarak tanımlanabileceği hiçbir Kişisel Veri toplamayacağız, bunlar arasında isimler, adresler, ödeme bilgileri veya telefon numaraları dahil olmamak üzere sınırlama olmaksızın bulunmaktadır. Bu hizmeti etkinleştirerek, bu şartları ve Gizlilik Politikası hakkındaki beyanı kabul etmiş olursunuz.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Avrupa",
		"t61": "North America",
		"t62": "Others",
		"t63": "Bölgeyi değiştirdikten sonra hesabınızdan çıkış yapılacaktır. Lütfen daha sonra tekrar giriş yapın.",
		"t64": "Bambu Ağı eklentisi",
		"t65": "WLAN veya bulut hizmeti üzerinden yazdırma işi gönderme",
		"t66": "Tam uzaktan kontrol",
		"t67": "Liveview akışı ve yazıcı durumu izlemesi",
		"t68": "Dilimleme yapılandırması için bulut eşitleme",
		"t69": "Bambu Ağı eklentisini yükleyin",
		"t70": "",
		"t71": "İndiriliyor",
		"t72": "İndirme başarısız oldu",
		"t73": "Kurulum başarılı oldu.",
		"t74": "Tekrar başlat",
		"t75": "Bambu Network eklentisi aşağıdaki özellikleri sağlar:",
		"t76": "Lütfen giriş yapmadan önce ağ eklentisini ",
		"t77": "yükleyin",
		"t78": "",
		"t79": "Eklenti yüklenemedi. ",
		"t80": "Aşağıdaki adımları deneyin:",
		"t81": "1, Eklenti ",
		"t82": " eklenti dizinini açmak için tıklayın.",
		"t83": "2, Tüm açık Bambu Studioyu kapatın ",
		"t84": "3, Eklenti dizini altındaki tüm dosyaları silin",
		"t85": "4, Bambu studioyu yeniden açın ve eklentiyi tekrar yükleyin",
		"t86": "Kapat",
		"t87": "Kullanım kılavuzu",
		"t88": "Kaldır",
		"t89": "Dosyayı içeren klasörü açınız",
		"t90": "3D Model",
		"t91": "3D modelleri İndirin",
		"t92": "Tarafından oluşturulmuştur",
		"t93": "Tarafından yeniden düzenlendi",
		"t94": "Tarafından paylaşıldı",
		"t95": "Model Bilgisi",
		"t96": "Aksesuarlar",
		"t97": "Profil Bilgisi",
		"t98": "Model adı",
		"t100": "Model açıklaması",
		"t101": "Parça Listesi",
		"t102": "Montaj Kılavuzu",
		"t103": "Diğer",
		"t104": "Profil adı",
		"t105": "Profil Yazarı",
		"t106": "Profil açıklaması",
		"t107": "Çevrimiçi Modeller",
		"t108": "DAHA FAZLA",
		"t109": "Sistem Filamentleri",
		"t110": "Özel Filamentler",
		"t111": "Yeni Oluştur",
		"t112": "Programa Katıl",
		"t113": "ercihlerinizde istediğiniz zaman seçiminizi değiştirebilirsiniz.",
		"t114": "Kitaplık",
		"t115": "Toplu",
		"t116": "Yeniden Dene",
		"t117": "Yazdırma geçmişi",
		"t118": "Yazdırılıyor",
		"t119": "Başarılı",
		"t120": "iptal edildi",
		"t121": "Arama",
		"t122": "Çevrimiçi modelleri arayın",
		"t123": "tabak",
		"t124": "",
		"t126": "Yükleme devam ediyor……",
		"wk17": "Bambu Lab Akademisi",
		"wk18": "Hızlı Başlangıç Kılavuzu",
		"wk19": "Konuya Göre Öğrenme",
		"wk20": "Filament Kılavuzu",
		"wk21": "Şimdi Keşfet"
	},
	"pt_BR": {
		"t1": "Bem-vindo ao Bambu Studio",
		"t2": "Bambu Studio será configurado em algumas etapas. Vamos começar!",
		"t3": "Termos de Uso",
		"t4": "Discordo",
		"t5": "Concordo",
		"t6": "Nós pedimos gentilmente sua ajuda para melhorar a impressão de todos.</br>Venha e junte-se ao nosso Programa de Melhoria de Experiência do Usuário",
		"t7": "Junte-se ao nosso Programa de Melhoria de Experiência do Usuário",
		"t8": "Voltar",
		"t9": "Próximo",
		"t10": "Seleção de Impressora",
		"t11": "Tudo",
		"t12": "Limpar tudo",
		"t13": "mm bico",
		"t14": "Seleção de Filamento",
		"t15": "Impressora",
		"t16": "Tipo de Filamento",
		"t17": "Fabricante",
		"t18": "Erro",
		"t19": "Pelo menos um filamento deve ser selecionado.",
		"t20": "Você deseja usar o filamento padrão?",
		"t21": "Sim",
		"t22": "Não",
		"t23": "Notas de Atualização",
		"t24": "Vamos Começar",
		"t25": "Terminar",
		"t26": "Entrar",
		"t27": "Registrar",
		"t28": "Modelos",
		"t29": "Loja",
		"t30": "Manual",
		"t31": "Novo Projeto",
		"t32": "Criar Novo Projeto",
		"t33": "Abrir Projeto",
		"t34": "hotspot",
		"t35": "Aberto Recentemente",
		"t36": "Ok",
		"t37": "Pelo menos uma impressora deve ser selecionada.",
		"t38": "Cancelar",
		"t39": "Confirmar",
		"t40": "Conexão desconectada, por favor cheque e tente novamente.",
		"t47": "Por favor, selecione sua região de login",
		"t48": "Asia-Pacifico",
		"t49": "China Continental",
		"t50": "Desconectar",
		"t52": "Pular",
		"t53": "Juntar-se",
		"t54": "Na comunidade de Impressão 3D, aprendemos com os sucessos e falhas uns dos outros para ajustar nossos próprios parâmetros e configurações de fatiamento. O Bambu Studio segue o mesmo princípio e utiliza aprendizado de máquina para melhorar seu desempenho com base nos sucessos e falhas de um grande número de impressões realizadas por nossos usuários. Estamos treinando o Bambu Studio para ser mais inteligente, alimentando-o com dados do mundo real. Se você concordar, este serviço acessará informações de seus registros de erros e registros de uso, que podem incluir informações descritas em ",
		"t55": "Política de Privacidade",
		"t56": ". Nós não coletaremos nenhum dado pessoal pelo qual um indivíduo possa ser identificado diretamente ou indiretamente, incluindo, sem limitação, nomes, endereços, informações de pagamento ou números de telefone. Ao habilitar este serviço, você concorda com estes termos e com a declaração sobre a Política de Privacidade.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "America do Norte",
		"t62": "Outras",
		"t63": "Após alterar sua região, sua conta será desconectada. Por favor conecte-se novamente mais tarde.",
		"t64": "Bambu Network plug-in",
		"t65": "Enviando trabalho de impressão via WLAN ou serviço de nuvem",
		"t66": "Controle remoto total",
		"t67": "Streaming do Liveview e monitoramento do status da impressora",
		"t68": "Sincronização em nuvem para configuração de fatiamento",
		"t69": "Instalar Bambu Network plug-in",
		"t70": "",
		"t71": "Baixando",
		"t72": "Baixando falhou",
		"t73": "Instalação concluida.",
		"t74": "Reiniciar",
		"t75": "Bambu Network plug-in fornece os seguintes recursos:",
		"t76": "",
		"t77": "Instale",
		"t78": " o plugin de rede antes de fazer login",
		"t79": "Instalação do plug-in falhou. ",
		"t80": "Tente os seguintes passos:",
		"t81": "1, Clique ",
		"t82": " para abrir a pasta do plug-in",
		"t83": "2, Feche totalmente o Bambu Studio",
		"t84": "3, Delete todos os arquivos na pasta do plug-in",
		"t85": "4, Reabra o Bambu Studio e instale o plug-in novamente",
		"t86": "Fechar",
		"t87": "Manual de Usuário",
		"t88": "Remover",
		"t89": "Abrir pasta de Conteúdo",
		"t90": "Modelo 3D",
		"t91": "Baixar Modelos 3D",
		"t92": "Criado por",
		"t93": "Remixado por",
		"t94": "Compartilhado por",
		"t95": "Informações do Modelo",
		"t96": "Acessórios",
		"t97": "Informações do Perfil",
		"t98": "Nome do Modelo",
		"t100": "Descrição do Modelo",
		"t101": "BOM",
		"t102": "Guia de Montagem",
		"t103": "Outro",
		"t104": "Nome do Perfil",
		"t105": "Autor do Perfil",
		"t106": "Descrição do Perfil",
		"t107": "Modelos Online",
		"t108": "MAIS",
		"t109": "Filamentos do Sistema",
		"t110": "Filamentos Personalizados",
		"t111": "Criar Novo",
		"t112": "Junte-se ao Programa",
		"t113": "Você pode alterar sua escolha nas Preferências a qualquer momento",
		"t114": "Biblioteca",
		"t115": "Lote",
		"t116": "Retentar",
		"t117": "Histórico de impressão",
		"t118": "Imprimindo",
		"t119": "Sucesso",
		"t120": "cancelado",
		"t121": "Pesquisa",
		"t122": "Procurar modelos online",
		"t123": "prato",
		"t124": "",
		"t126": "Carregamento em andamento……",
		"wk17": "Academia Bambu Lab",
		"wk18": "Tutorial de Início Rápido",
		"wk19": "Aprendizado por Tópico",
		"wk20": "Guia de Filamento",
		"wk21": "Explore Agora"
	},
	"ko_KR": {
		"t1": "Bambu Studio에 오신 것을 환영합니다",
		"t2": "Bambu Studio는 몇 단계로 설정됩니다. 시작해 봅시다!",
		"t3": "사용자 계약",
		"t4": "동의하지 않음",
		"t5": "동의함",
		"t6": "모든 사람의 프린팅을 개선하기 위해 귀하의 도움을 부탁드립니다.<br/>고객 경험 개선 프로그램에 참여해 주세요",
		"t7": "고객 경험 개선 프로그램에 참여해 주세요",
		"t8": "뒤로",
		"t9": "다음",
		"t10": "프린터 선택",
		"t11": "전체",
		"t12": "모두 지우기",
		"t13": "mm 노즐",
		"t14": "필라멘트 선택",
		"t15": "프린터",
		"t16": "필라멘트 유형",
		"t17": "공급업체",
		"t18": "오류",
		"t19": "최소한 하나의 필라멘트를 선택해야 합니다.",
		"t20": "기본 필라멘트를 사용하시겠습니까?",
		"t21": "예",
		"t22": "아니오",
		"t23": "릴리스 노트",
		"t24": "시작하기",
		"t25": "완료",
		"t26": "로그인",
		"t27": "등록",
		"t28": "모델",
		"t29": "몰",
		"t30": "수동",
		"t31": "새 프로젝트",
		"t32": "새 프로젝트 생성",
		"t33": "프로젝트 열기",
		"t34": "ホットスポット",
		"t35": "최근에 열었습니다",
		"t36": "확인",
		"t37": "최소한 하나의 프린터를 선택해야 합니다.",
		"t38": "취소",
		"t39": "확인",
		"t40": "네트워크가 연결되지 않았습니다. 확인 후 다시 시도해 주세요.",
		"t47": "로그인 지역을 선택해 주세요",
		"t48": "아시아 태평양",
		"t49": "중국 대륙",
		"t50": "로그 아웃",
		"t52": "건너뛰기",
		"t53": "가입",
		"t54": "3D 프린팅 커뮤니티에서는 우리는 서로의 성공과 실패로부터 배우고, 자신의 스라이싱 매개변수와 설정을 조정합니다. Bambu Studio 역시 같은 원리로 사용자의 성공과 실패로부터 기계 학습을 사용하여 그 성능을 개선합니다. 우리는 실제 세계의 데이터를 제공함으로써 Bambu Studio를 더 똑똑하게 훈련하고 있습니다. 여러분이 원할 경우, 이 서비스는 오류 로그와 사용 로그의 정보에 접근할 것입니다. 이 정보에는 다음에 설명된 정보가 포함될 수 있습니다.",
		"t55": "개인정보 정책",
		"t56": ". 우리는 개인을 직접 또는 간접적으로 식별할 수 있는 개인 정보를 수집하지 않습니다. 이는 이름, 주소, 결제 정보, 또는 전화번호 등을 포함하지만, 이에 국한되지 않습니다. 이 서비스를 사용함으로써, 이러한 조항과 개인정보 정책에 관한 설명에 동의하는 것입니다.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "유럽",
		"t61": "북미",
		"t62": "기타",
		"t63": "지역을 변경한 후, 귀하의 계정은 로그아웃됩니다. 나중에 다시 로그인해 주세요.",
		"t64": "Bambu Network 플러그인",
		"t65": "WLAN 또는 클라우드 서비스를 통해 인쇄 작업 보내기",
		"t66": "완전한 원격 제어",
		"t67": "라이브뷰 스트리밍 및 프린터 상태 모니터링",
		"t68": "슬라이싱 설정의 클라우드 동기화",
		"t69": "Bambu Network 플러그인 설치",
		"t70": "",
		"t71": "다운로드 중",
		"t72": "다운로드 실패",
		"t73": "설치 성공.",
		"t74": "재시작",
		"t75": "Bambu Network 플러그인은 다음 기능을 제공합니다:",
		"t76": "로그인하기 전에 네트워크 플러그인을 ",
		"t77": "설치해 주세요",
		"t78": "",
		"t79": "플러그인 설치에 실패했습니다. ",
		"t80": "다음 단계를 시도해 보십시오:",
		"t81": "1, 클릭",
		"t82": "플러그인 디렉토리 열기",
		"t83": "2, 모든 Bambu Studio 종료",
		"t84": "3, 플러그인 디렉토리의 모든 파일 삭제",
		"t85": "4, Bambu Studio 다시 열고 플러그인 다시 설치",
		"t86": "닫기",
		"t87": "사용자 매뉴얼",
		"t88": "제거",
		"t89": "포함 폴더 열기",
		"t90": "3D 모델",
		"t91": "3D 모델 다운로드",
		"t92": "만든이",
		"t93": "리믹스한 이",
		"t94": "공유한 이",
		"t95": "모델 정보",
		"t96": "액세서리",
		"t97": "프로필 정보",
		"t98": "모델 이름",
		"t100": "모델 설명",
		"t101": "BOM",
		"t102": "조립 가이드",
		"t103": "기타",
		"t104": "프로필 이름",
		"t105": "프로필 작가",
		"t106": "프로필 설명",
		"t107": "온라인 모델",
		"t108": "더보기",
		"t109": "시스템 필라멘트",
		"t110": "커스텀 필라멘트",
		"t111": "새로 만들기",
		"t112": "프로그램 참여",
		"t113": "언제든지 환경 설정에서 선택을 변경할 수 있습니다.",
		"t114": "라이브러리",
		"t115": "일괄 처리",
		"t116": "재시도",
		"t117": "인쇄 기록",
		"t118": "인쇄 중",
		"t119": "성공",
		"t120": "취소된",
		"t121": "검색",
		"t122": "온라인 모델을 검색하다",
		"t123": "접시",
		"t124": "",
		"t126": "로딩 중……",
		"wk17": "밤부랩 아카데미",
		"wk18": "빠른 시작 튜토리얼",
		"wk19": "주제별 학습",
		"wk20": "필라멘트 가이드",
		"wk21": "지금 탐색"
	},
	"pl_PL": {
		"t1": "Witamy w Bambu Studio",
		"t2": "Konfiguracja Bambu Studio będzie realizowana w kilka etapach. Zaczynajmy!",
		"t3": "Umowa Użytkownika",
		"t4": "Nie zgadzam się",
		"t5": "Zgadzam się",
		"t6": "Prosimy o Twoją pomoc w polepszeniu wydruków dla wszystkich.<br/>Dołącz do naszego Programu Polepszenia Doświadczenia Klienta",
		"t7": "Dołącz do naszego Programu Polepszenia Doświadczenia Klienta",
		"t8": "Wstecz",
		"t9": "Dalej",
		"t10": "Wybór drukarki",
		"t11": "Wszystkie",
		"t12": "Wyczyść wszystko",
		"t13": "dysza mm",
		"t14": "Wybór filamentu",
		"t15": "Drukarka",
		"t16": "Typ filamentu",
		"t17": "Producent",
		"t18": "błąd",
		"t19": "Musisz wybrać przynajmniej jeden filament.",
		"t20": "Czy chcesz użyć domyślnego filamentu?",
		"t21": "tak",
		"t22": "nie",
		"t23": "Informacje o wydaniu",
		"t24": "Rozpocznij",
		"t25": "Zakończ",
		"t26": "Logowanie",
		"t27": "Rejestracja",
		"t28": "Modele",
		"t29": "Sklep",
		"t30": "Instrukcja",
		"t31": "Nowy projekt",
		"t32": "Utwórz nowy projekt",
		"t33": "Otwórz projekt",
		"t34": "punkt aktywny",
		"t35": "Ostatnio otwarte pliki",
		"t36": "ok",
		"t37": "Musisz wybrać przynajmniej jedną drukarkę.",
		"t38": "Anuluj",
		"t39": "Potwierdź",
		"t40": "Rozłączono od sieci, proszę sprawdzić i spróbować ponownie później.",
		"t47": "Proszę wybrać region logowania",
		"t48": "Azja i Pacyfik",
		"t49": "Chiny",
		"t50": "Wyloguj",
		"t52": "Pomiń",
		"t53": "Dołącz",
		"t54": "W społeczności 3D drukowania uczymy się od sukcesów i porażek innych, aby dostosować swoje własne parametry ciągów i ustawienia. Bambu Studio działa według tej samej zasady i używa uczenia maszynowego, aby poprawić swoją wydajność na podstawie sukcesów i niepowodzeń licznych wydruków naszych użytkowników. Trenujemy Bambu Studio, aby stać się bardziej inteligentnym, podając mu rzeczywiste dane z świata. Jeśli jesteś zgodny, ta usługa będzie mogła uzyskać dostęp do informacji z Twoich dzienników błędów i dzienników użycia, które mogą zawierać informacje opisane w",
		"t55": "Polityka prywatności",
		"t56": ". Nie będziemy zbierać żadnych danych osobowych, które pozwolą na bezpośrednie lub pośrednie zidentyfikowanie osoby, w tym, ale nie ograniczając się do nazwisk, adresów, informacji o płatności lub numerów telefonów. Włączając tę usługę, akceptujesz te warunki i oświadczenie dotyczące Polityki prywatności.",
		"t57": "",
		"t58": "",
		"t59": ".",
		"t60": "Europa",
		"t61": "Ameryka Północna",
		"t62": "Inne",
		"t63": "Po zmianie regionu Twoje konto zostanie wylogowane. Zaloguj się ponownie później.",
		"t64": "Wtyczka Bambu Network",
		"t65": "Wysyłanie zadania drukowania przez WLAN lub usługę cloud",
		"t66": "Pełne zdalne sterowanie",
		"t67": "Strumieniowe przesyłanie Liveview i monitorowanie stanu drukarki",
		"t68": "Synchronizacja chmurowa konfiguracji krojenia",
		"t69": "Zainstaluj wtyczkę Bambu Network",
		"t70": "",
		"t71": "Pobieranie",
		"t72": "Pobieranie nie powiodło się",
		"t73": "Instalacja zakończona sukcesem.",
		"t74": "Uruchom ponownie",
		"t75": "Wtyczka Bambu Network zapewnia następujące funkcje:",
		"t76": "",
		"t77": "Zainstaluj",
		"t78": " wtyczkę sieciową przed zalogowaniem się",
		"t79": "Nie udało się zainstalować wtyczki. ",
		"t80": "Wypróbuj następujące kroki:",
		"t81": "1, Kliknij",
		"t82": "aby otworzyć katalog wtyczki",
		"t83": "2, Zamknij wszystkie otwarte Bambu Studio",
		"t84": "3, Usuń wszystkie pliki w katalogu wtyczki",
		"t85": "4, Otwórz ponownie Bambu Studio i zainstaluj wtyczkę ponownie",
		"t86": "Zamknij",
		"t87": "Instrukcja obsługi",
		"t88": "Usuń",
		"t89": "Otwórz folder zawierający",
		"t90": "Model 3D",
		"t91": "Pobierz modele 3D",
		"t92": "Utworzone przez",
		"t93": "Remixowane przez",
		"t94": "Udostępnione przez",
		"t95": "Informacje o modelu",
		"t96": "Akcesoria",
		"t97": "Informacje o profilu",
		"t98": "Nazwa modelu",
		"t100": "Opis modelu",
		"t101": "BOM",
		"t102": "Przewodnik montażu",
		"t103": "Inne",
		"t104": "Nazwa profilu",
		"t105": "Autor profilu",
		"t106": "Opis profilu",
		"t107": "Modele online",
		"t108": "Więcej",
		"t109": "Filamenty systemowe",
		"t110": "Filamenty niestandardowe",
		"t111": "Utwórz nowy",
		"t112": "Dołącz do programu",
		"t113": "Opcja można zmienić w preferencjach w dowolnym momencie.",
		"t114": "Biblioteka",
		"t115": "Wartość zbiorcza",
		"t116": "Ponów",
		"t117": "Historia druku",
		"t118": "Drukuje się",
		"t119": "Sukces",
		"t120": "anulowany",
		"t121": "Wyszukiwanie",
		"t122": "Wyszukaj modele online",
		"t123": "talerz",
		"t124": "",
		"t126": "Ładowanie trwa……",
		"wk17": "Akademia Bambu Lab",
		"wk18": "Samouczek Szybkiego Startu",
		"wk19": "Nauka według Tematu",
		"wk20": "Przewodnik po Filamentach",
		"wk21": "Odkrywaj teraz"
	}
};

var LANG_COOKIE_NAME="BambuWebLang";
var LANG_COOKIE_EXPIRESECOND= 365*86400;

function TranslatePage()
{
	let strLang=GetQueryString("lang");
	if(strLang!=null)
	{
		//setCookie(LANG_COOKIE_NAME,strLang,LANG_COOKIE_EXPIRESECOND,'/');
		localStorage.setItem(LANG_COOKIE_NAME,strLang);
	}
	else
	{
		//strLang=getCookie(LANG_COOKIE_NAME);
		strLang=localStorage.getItem(LANG_COOKIE_NAME);
	}
	
	//alert(strLang);
	
	if( !LangText.hasOwnProperty(strLang) )
		strLang="en";

    let AllNode=$(".trans");
	let nTotal=AllNode.length;
	for(let n=0;n<nTotal;n++)
	{
		let OneNode=AllNode[n];
		
		let tid=$(OneNode).attr("tid");
		if( LangText[strLang].hasOwnProperty(tid) )
		{
			$(OneNode).html(LangText[strLang][tid]);
		}
		else if(strLang!='en' && LangText['en'].hasOwnProperty(tid) )
		{
			$(OneNode).html(LangText['en'][tid]);
		}		
	}
}

function GetCurrentTextByKey( key )
{
	let strLang=GetQueryString("lang");
	if(strLang!=null)
	{
		//setCookie(LANG_COOKIE_NAME,strLang,LANG_COOKIE_EXPIRESECOND,'/');
		localStorage.setItem(LANG_COOKIE_NAME,strLang);
	}
	else
	{
		//strLang=getCookie(LANG_COOKIE_NAME);
		strLang=localStorage.getItem(LANG_COOKIE_NAME);
	}
	
	//alert(strLang);
	
	if( !LangText.hasOwnProperty(strLang) )
		strLang="en";

	let strText='';
	if( LangText[strLang].hasOwnProperty(key) )
	{
		strText=LangText[strLang][key];
	}
	else if(strLang!='en' && LangText['en'].hasOwnProperty(key) )
	{
		strText=LangText['en'][key];
	}	
	
	return strText;
}
